@@ -60,7 +60,7 @@ def camera_store_with_scene(self_cmd,frame):
 
 
 def store_with_state(self_cmd,obj='',frame=0):
-    n_state = self_cmd.count_states()
+    n_state = self_cmd.count_states('%' + obj if obj else '')
     result = [[ 2, 'State:', ''],
               [ 1, 'current','cmd.mview("store",object="'+obj+'",state=-1,first=%s)'%(frame)],
               [ 0, ''               ,''                   ],
@@ -70,12 +70,11 @@ def store_with_state(self_cmd,obj='',frame=0):
         result.extend([
               [ 1, str(n_state),'cmd.mview("store",object="'+obj+'",state=%d,first=%s)'%(n_state,frame)],
               [ 0, ''               ,''                   ],
-              [ 1, str(1+n_state/4), 'cmd.mview("store",object="'+obj+'",state=%d,first=%s)'%(1+n_state/4,frame) ],
-              [ 1, str(1+n_state/3), 'cmd.mview("store",object="'+obj+'",state=%d,first=%s)'%(1+n_state/3,frame) ],
-              [ 1, str(n_state/2), 'cmd.mview("store",object="'+obj+'",state=%d,first=%s)'%(n_state/2,frame) ],
-              [ 1, str(1+n_state/2), 'cmd.mview("store",object="'+obj+'",state=%d,first=%s)'%(1+n_state/2,frame) ],
-              [ 1, str((2*n_state)/3), 'cmd.mview("store",object="'+obj+'",state=%d,first=%s)'%((2*n_state)/3,frame) ],
-              [ 1, str((3*n_state)/4), 'cmd.mview("store",object="'+obj+'",state=%d,first=%s)'%((3*n_state)/4,frame) ],
+              ])
+        n_show = min(8, n_state)
+        result.extend([
+              [ 1, str(state), 'cmd.mview("store",object="'+obj+'",state=%d,first=%s)'%(state,frame) ]
+              for state in [(n_state * i) // n_show for i in range(2, n_show)]
               ])
 
     return result
@@ -145,18 +144,22 @@ def obj_motion(self_cmd, obj, frame="0"):
 
 def rep_action(self_cmd, sele, action) :
     return [
-        [ 1, 'lines'      , 'cmd.'+action+'("lines"     ,"'+sele+'")' ],
-        [ 1, 'sticks'     , 'cmd.'+action+'("sticks"    ,"'+sele+'")' ],
+        [ 1, 'wire'       , 'cmd.'+action+'("wire"      ,"'+sele+'")' ],
+        [ 1, '  lines'    , 'cmd.'+action+'("lines"     ,"'+sele+'")' ],
+        [ 1, '  nonbonded', 'cmd.'+action+'("nonbonded" ,"'+sele+'")' ],
+        [ 0, ''           , ''                               ],
+        [ 1, 'licorice'   , 'cmd.'+action+'("licorice"  ,"'+sele+'")' ],
+        [ 1, '  sticks'   , 'cmd.'+action+'("sticks"    ,"'+sele+'")' ],
+        [ 1, '  nb_spheres','cmd.'+action+'("nb_spheres","'+sele+'")' ],
+        [ 0, ''           , ''                               ],
         [ 1, 'ribbon'     , 'cmd.'+action+'("ribbon"    ,"'+sele+'")' ],
         [ 1, 'cartoon'    , 'cmd.'+action+'("cartoon"   ,"'+sele+'")' ],
         [ 0, ''           , ''                               ],
         [ 1, 'label'      , 'cmd.'+action+'("labels"    ,"'+sele+'")' ],
         [ 1, 'cell'       , 'cmd.'+action+'("cell"      ,"'+sele+'")' ],
         [ 0, ''           , ''                               ],
-        [ 1, 'nonbonded'  , 'cmd.'+action+'("nonbonded" ,"'+sele+'")' ],
         [ 1, 'dots'       , 'cmd.'+action+'("dots"      ,"'+sele+'")' ],
         [ 1, 'spheres'    , 'cmd.'+action+'("spheres"   ,"'+sele+'")' ],
-        [ 1, 'nb_spheres' , 'cmd.'+action+'("nb_spheres","'+sele+'")' ],
         [ 0, ''           , ''                               ],
         [ 1, 'mesh'       , 'cmd.'+action+'("mesh"      ,"'+sele+'")' ],
         [ 1, 'surface'    , 'cmd.'+action+'("surface"   ,"'+sele+'")' ],
@@ -835,6 +838,7 @@ def selection(self_cmd, sele):
               [ 1, 'donors', 'cmd.select("'+sele+'_donors","('+sele+') and hbd")'],
               [ 1, 'acceptors', 'cmd.select("'+sele+'_acceptors","('+sele+') and hba")'],           
               [ 1, 'surface atoms', 'util.find_surface_atoms(sele="'+sele+'", _self=cmd)' ],
+              [ 1, 'C-alphas', 'cmd.select("'+sele+'_calpha","bycalpha ('+sele+')")'],
               ]
 
 def mol_generate(self_cmd, sele):
@@ -1095,6 +1099,19 @@ def modify_sele(self_cmd, sele):
               [ 1, 'include'        , include(self_cmd, sele)       ],
               [ 1, 'exclude'        , exclude(self_cmd, sele)       ]]
 
+
+def copy_to(self_cmd, sele):
+    onames = self_cmd.get_object_list('enabled')[:25]  # keep this practical
+    selected = self_cmd.get_object_list(sele)
+    return [[ 2, 'Copy To:', '' ],
+              [ 1, 'new', 'cmd.create(None,"' + sele + '",zoom=0)' ],
+              [ 0, '', '' ],
+              ] + [
+                  [ 1, oname, 'cmd.copy_to("' + oname + '","' + sele + '",zoom=0,quiet=0)' ]
+                  for oname in onames
+                  if oname not in selected
+              ]
+
               
 def sele_action(self_cmd, sele):
     return [[ 2, 'Action:'       ,''                        ],     
@@ -1118,7 +1135,7 @@ def sele_action(self_cmd, sele):
               [ 1, 'hydrogens' , hydrogens(self_cmd, sele) ],
               [ 0, ''          ,''                                              ],
               [ 1, 'duplicate'      ,'cmd.select(None,"'+sele+'")'          ], # broken...
-              [ 1, 'copy to object' ,'cmd.create(None,"'+sele+'",zoom=0)'     ],
+              [ 1, 'copy to object' , lambda: copy_to(self_cmd, sele) ],
               [ 1, 'extract object' ,'cmd.extract(None,"'+sele+'",zoom=0)' ],
               [ 0, ''          ,''                                  ],
               [ 1, 'masking'        , masking(self_cmd, sele)         ],
@@ -1144,7 +1161,7 @@ def sele_action2(self_cmd, sele):
               [ 1, 'complete'       , complete(self_cmd, sele)         ],
               [ 0, ''          ,''                                              ],
               [ 1, 'duplicate selection'      ,'cmd.select(None,"'+sele+'")'          ],
-              [ 1, 'copy to object'  ,'cmd.create(None,"'+sele+'",zoom=0)'     ],           
+              [ 1, 'copy to object' , lambda: copy_to(self_cmd, sele) ],
               [ 1, 'extract object' ,'cmd.extract(None,"'+sele+'",zoom=0)' ],
             [ 0, ''          ,''                                  ],
               [ 1, 'masking'      , masking(self_cmd, sele)         ],
@@ -1204,7 +1221,7 @@ def mol_action(self_cmd, sele):
             [ 1, 'assign sec. struc.'  ,'cmd.dss("'+sele+'")'        ],
             [ 0, ''             , ''                       ],
             [ 1, 'rename object', 'cmd.wizard("renaming","'+sele+'")'          ],
-            [ 1, 'duplicate object'    ,'cmd.create(None,"'+sele+'")'     ],           
+            [ 1, 'copy to object' , lambda: copy_to(self_cmd, sele) ],
             [ 1, del_col + 'delete object', 'cmd.delete("'+sele+'")'    ],
             [ 0, ''          ,''                                              ],
             [ 1, 'hydrogens' , hydrogens(self_cmd, sele)    ],           
@@ -1479,12 +1496,14 @@ def mol_labels(self_cmd, sele):
               [ 1, 'clear'          , 'cmd.label("'+sele+'","\'\'")'         ],
               [ 0, ''               , ''                                  ],
               [ 1, 'residues'       , """cmd.label('''(name """+self_cmd.get("label_anchor")+"""+C1*+C1' and (byres("""+sele+""")))''','''"%s-%s"%(resn,resi)''')"""  ],
+              [ 1, 'residues (oneletter)', "cmd.label('''byca(" + sele + ")''', 'oneletter+resi')"],
               [ 1, 'chains'       ,   'util.label_chains("'+sele+'",_self=cmd)'  ],
               [ 1, 'segments'       ,   'util.label_segments("'+sele+'",_self=cmd)'  ],           
               [ 0, ''               , ''                                  ],           
               [ 1, 'atom name'      , 'cmd.label("'+sele+'","name")'         ],
               [ 1, 'element symbol' , 'cmd.label("'+sele+'","elem")'         ],           
               [ 1, 'residue name'  , 'cmd.label("'+sele+'","resn")'         ],
+              [ 1, 'one letter code', 'cmd.label("'+sele+'","oneletter")' ],
               [ 1, 'residue identifier'    , 'cmd.label("'+sele+'","resi")'         ],
               [ 1, 'chain identifier' , 'cmd.label("'+sele+'","chain")'         ],
               [ 1, 'segment identifier'       , 'cmd.label("'+sele+'","segi")'         ],           
@@ -1567,7 +1586,7 @@ def scene_main(self_cmd):
         [ 0, ''             , ''                      ],        
         [ 1, 'buttons', scene_buttons(self_cmd)] ]
 
-def main_pseudoatom_sub(self_cmd,pos):
+def main_pseudoatom_sub(self_cmd,pos, screenpos):
     return [
         [ 2, 'Pseudoatom' ,'' ],
         [ 1, 'label' ,'cmd.wizard("pseudoatom","label",pos=[%1.7f,%1.7f,%1.7f])'%pos ],
@@ -1575,10 +1594,10 @@ def main_pseudoatom_sub(self_cmd,pos):
         [ 1, 'single ', 'cmd.pseudoatom(pos=[%1.7f,%1.7f,%1.7f])'%pos ],
         ]
 
-def main_pseudoatom(self_cmd,pos):
+def main_pseudoatom(self_cmd,pos, screenpos):
     return [
         [ 2, 'New'  , '' ],
-        [ 1, 'pseudoatom' , main_pseudoatom_sub(self_cmd,pos) ],
+        [ 1, 'pseudoatom' , main_pseudoatom_sub(self_cmd,pos, screenpos) ],
         ]
 
 def movie_panel(self_cmd):
@@ -1597,10 +1616,10 @@ def movie_main(self_cmd):
         [ 1, 'panel', movie_panel(self_cmd) ]
         ]
 
-def main_menu(self_cmd,pos):
+def main_menu(self_cmd,pos, screenpos):
     return [
         [ 2, 'Main Pop-Up'  , '' ],
-        [ 1, 'new'             , main_pseudoatom(self_cmd,pos) ],        
+        [ 1, 'new'             , main_pseudoatom(self_cmd,pos, screenpos) ],
         [ 0, ''             , ''                      ],
         [ 1, 'zoom (vis)'           ,'cmd.zoom("visible",animate=-1)'            ],
         [ 1, 'orient (vis)'           ,'cmd.orient("visible",animate=-1)'            ],
@@ -1623,17 +1642,6 @@ def main_menu(self_cmd,pos):
         [ 1, del_col + 'quit', 'cmd.quit()' ],
         ]
 
-def pick_sele_sub(self_cmd, sele):
-    result = [
-        [ 2, 'Actions'  , '' ],      
-        [ 1, 'rename', 'cmd.wizard("renaming","'+sele+'")'          ],
-        [ 1, 'clear'    , 'cmd.select("'+sele+'","none")' ],
-        [ 1, del_col + 'delete selection', 'cmd.delete("'+sele+'")' ],
-        [ 1, 'copy to object','cmd.create(None,"'+sele+'",zoom=0)'            ],
-        [ 1, 'extract object' ,'cmd.extract(None,"'+sele+'",zoom=0)' ],
-        [ 1, rem_col + 'remove atoms', 'cmd.remove("'+sele+'")' ],
-        ]
-    return result
 
 def pick_sele(self_cmd, sele, title):
     result = [
@@ -1662,10 +1670,7 @@ def pick_sele(self_cmd, sele, title):
     
 def pick_option(self_cmd, sele, title, object=0):
     if object:
-        save_sele = sele
-        sele = "(byobj ("+sele+"))"
-    else:
-        save_sele = sele
+        sele = self_cmd.identify(sele, 1)[0][0]
     result = [
         [ 2, title, '' ],
         [ 1, 'color'      , lambda: mol_color(self_cmd, sele) ],
@@ -1683,7 +1688,7 @@ def pick_option(self_cmd, sele, title, object=0):
 
     if object:
         result.append([ 1, 'drag'             ,   [[ 1, 'coordinates', 'cmd.drag("'+sele+'")'],
-                                     [ 1, 'matrix', 'cmd.drag("'+save_sele+'",mode=1)']]])
+                                     [ 1, 'matrix', 'cmd.drag("'+sele+'",mode=1)']]])
     else:
         result.append([ 1, 'drag'   ,  'cmd.drag("'+sele+'")'])
         
@@ -1703,15 +1708,11 @@ def pick_option(self_cmd, sele, title, object=0):
         result.extend([
             [ 1, rem_col + 'remove atoms', 'cmd.remove("'+sele+'")' ],
             [ 0, ''             , ''                      ],      
-            [ 1, 'copy to object','cmd.create(None,"'+sele+'",zoom=0)'            ],
+            [ 1, 'copy to object' , lambda: copy_to(self_cmd, sele) ],
             [ 1, 'extract object' ,'cmd.extract(None,"'+sele+'",zoom=0)' ],
             ])
     return result
 
-def pick_option_rev(self_cmd, sele, title, object=0):
-    result = pick_option(self_cmd, sele, title, object)[1:]
-    result.reverse()
-    return result
 
 def pick_menu(self_cmd, title, sele2):
     with menucontext(self_cmd, sele2):
